==> open-aea-1.22.0.tar.gz: open-aea-1.22.0/docs/package_list.md <==
| Package name                                                  | Package hash                                                  |
| ------------------------------------------------------------- | ------------------------------------------------------------- |
| protocol/fetchai/gym/1.0.0                                    | `bafybeihpjm2sgnrpuwaqicikw4aybltm7xrjmf7cscpp2cy2xdoi6pekbq` |
| connection/fetchai/gym/0.19.0                                 | `bafybeiak5qnlo4b6ai5ep5cp5tyw26dyv5finwjcbwo3aryhtjqmdl2keu` |
| protocol/fetchai/default/1.0.0                                | `bafybeihzesahyayexkhk26fg7rqnjuqaab3bmcijtjekvskvs4xw6ecyuu` |
| protocol/valory/acn/1.1.0                                     | `bafybeifontek6tvaecatoauiule3j3id6xoktpjubvuqi3h2jkzqg7zh7a` |
| protocol/valory/contract_api/1.0.0                            | `bafybeiaxbrvgtbdrh4lslskuxyp4awyr4whcx3nqq5yrr6vimzsxg5dy64` |
| protocol/valory/http/1.0.0                                    | `bafybeigzqo2zaakcjtzzsm6dh4x73v72xg6ctk6muyp5uq5ueb7y34fbxy` |
| protocol/valory/ledger_api/1.0.0                              | `bafybeih7rhi5zvfvwakx5ifgxsz2cfipeecsh7bm3gnudjxtvhrygpcftq` |
| connection/fetchai/http_server/0.22.0                         | `bafybeiaf2w3jfemqu4zrtfzewexh5ttqytvhv4tqfzcrv6qxsqnxrv7eu4` |
| connection/fetchai/stub/0.21.0                                | `bafybeieqlozydyvdxmjxhqygwq27djecpiftoqwlcpcr4qpotomwnh66yy` |
| connection/valory/ledger/0.19.0                               | `bafybeiadc25se7dgnn4mufztwpzdono4xsfs45qknzdqyi3gckn6ccuv44` |
| connection/valory/p2p_libp2p/0.1.0                            | `bafybeibjirmffnyih5gplt2uu6ojvta25w7up6yt447unungn4xpgqn5ca` |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeidkk33xbga54szmitk6uwsi3ef56hbbdbuasltqtiyki34hgfpnxa` |
| connection/valory/p2p_libp2p_mailbox/0.1.0                    | `bafybeihjjsenbsgh6x2vukea7mqzsbcbqqbog6xa43raen24ewqf4qq3pm` |
| contract/fetchai/erc1155/0.22.0                               | `bafybeid4i7dwsulgnwaylzk6xcozewkgacymxhwk2ip5omvccluq2pm7ii` |
| protocol/fetchai/fipa/1.0.0                                   | `bafybeih27chr3b3anjeq26yd5c2p3hypp4sijzdu6yrorpwwxnvkeoa2ei` |
| protocol/fetchai/oef_search/1.0.0                             | `bafybeifiec4jvsa6mcbmasjno3bwvjwwwubyp25hjqwe7gjfksgvwgdisq` |
| protocol/fetchai/state_update/1.0.0                           | `bafybeidtndlmppst6l6iughpflqbbbkzditixo2fy2dncxfkb5apkx5y4m` |
| protocol/open_aea/signing/1.0.0                               | `bafybeiambqptflge33eemdhis2whik67hjplfnqwieoa6wblzlaf7vuo44` |
| skill/fetchai/echo/0.19.0                                     | `bafybeia3ovoxmnipktwnyztie55itsuempnfeircw72jn62uojzry5pwsu` |
| skill/fetchai/error_test_skill/0.1.0                          | `bafybeihsbtlpe7h6fsvoxban5rilkmwviwkokul5cqym6atoolirontiyu` |
| skill/fetchai/gym/0.20.0                                      | `bafybeid53vlpk2jwdzqf7a5xh4q5653wg46h7eg7pq66c3pmmgwnwjnsja` |
| skill/fetchai/http_echo/0.20.0                                | `bafybeickwfnhufcaift5k6uspltvhatdpmppyhfzghewecctgq72dgu5a4` |
| agent/fetchai/error_test/0.1.0                                | `bafybeigercyzr4qscyf4bp22jwehyoxhcix6yyuxhfec2n5umns3qcm7aq` |
| agent/fetchai/gym_aea/0.25.0                                  | `bafybeic7lugvrrlcre42evfnttonheppvpvupg3wgraizkyrorheicooem` |
| agent/fetchai/my_first_aea/0.27.0                             | `bafybeic6plxxhcbokxlce3grbgsm247rgvcb5arwwslm5yv6pt46byr22a` |
| agent/open_aea/gym_aea/0.1.0                                  | `bafybeidkfolcgqh5mmdcmd7vee74avhicgiahdyiflyylanowxmqc7bxni` |
| agent/open_aea/http_echo/0.1.0                                | `bafybeihxe5mk2gs6k3xxf5rgaqqa5ij2ff74gebcwxskc2dpxvt5rcnyxi` |
| agent/open_aea/my_first_aea/0.1.0                             | `bafybeifelwg4md24lwpxgx7x5cugq7ovhbkew3lxw43m52rdppfn5o5g4i` |
| connection/fetchai/local/0.20.0                               | `bafybeianwid4lh3ubjheg4ho7qznuib2t6k35rcuconcbwtzmih4qdxo2i` |
| connection/valory/http_client/0.23.0                          | `bafybeihz3tubwado7j3wlivndzzuj3c6fdsp4ra5r3nqixn3ufawzo3wii` |
| connection/valory/test_libp2p/0.1.0                           | `bafybeibnqzgf76bu2cqa7n3seeju3j7ukkorddb6n2xzx4bynh4swdk43q` |
| protocol/fetchai/tac/1.0.0                                    | `bafybeiaew226n32rwp3h57zl4b2mmbrhjbyrdjbl2evnxf2tmmi4vrls7a` |
| skill/fetchai/erc1155_client/0.28.0                           | `bafybeigjapreaqjqvcukrnqr4fzlrugl3635bh2abj3tnxqq247swqtl7u` |
| skill/fetchai/erc1155_deploy/0.30.0                           | `bafybeibtjaylkd47ghbwgl7rdck2exvnrodwnyjhfvrtaluwrvkx5k5gtq` |
| skill/fetchai/error/0.17.0                                    | `bafybeib7nhokw3bc46oxuk5mjazan42evipowmka2ikfcs6drcdz4mwkjm` |
| skill/fetchai/fipa_dummy_buyer/0.2.0                          | `bafybeiha4jultg5srhr2ijplvubeo7esv4raq2cjlggmyzcaimop2ggg2m` |
| skill/fetchai/generic_buyer/0.26.0                            | `bafybeidecu4tnhmbyzbysgccgtpsstj4q5hfqjgjzm5nf2hdb7hf6fnx2q` |
| skill/fetchai/generic_seller/0.27.0                           | `bafybeidjpgp323esan54fjxr6xqnq365oqi5g45p3nts67e3su6u4kss3y` |
| skill/fetchai/task_test_skill/0.1.0                           | `bafybeidv77u2xl52mnxakwvh7fuh46aiwfpteyof4eaptfd4agoi6cdble` |

==> open-aea-1.27.0.tar.gz: open-aea-1.27.0/docs/package_list.md <==
| Package name                                                  | Package hash                                                  |
| ------------------------------------------------------------- | ------------------------------------------------------------- |
| protocol/fetchai/gym/1.0.0                                    | `bafybeihpjm2sgnrpuwaqicikw4aybltm7xrjmf7cscpp2cy2xdoi6pekbq` |
| connection/fetchai/gym/0.19.0                                 | `bafybeicehd5z4aktwtffytkrqiq7b4ui2grdf4yvqfpiczjp3gtmmxngqu` |
| protocol/fetchai/default/1.0.0                                | `bafybeihzesahyayexkhk26fg7rqnjuqaab3bmcijtjekvskvs4xw6ecyuu` |
| protocol/valory/acn/1.1.0                                     | `bafybeifontek6tvaecatoauiule3j3id6xoktpjubvuqi3h2jkzqg7zh7a` |
| protocol/valory/contract_api/1.0.0                            | `bafybeiaxbrvgtbdrh4lslskuxyp4awyr4whcx3nqq5yrr6vimzsxg5dy64` |
| protocol/valory/http/1.0.0                                    | `bafybeigzqo2zaakcjtzzsm6dh4x73v72xg6ctk6muyp5uq5ueb7y34fbxy` |
| protocol/valory/ledger_api/1.0.0                              | `bafybeih7rhi5zvfvwakx5ifgxsz2cfipeecsh7bm3gnudjxtvhrygpcftq` |
| connection/fetchai/http_server/0.22.0                         | `bafybeidxb5gk3samqoflbztqnlnqtvtph5emobaojx3w47674ay5d7pmeu` |
| connection/fetchai/stub/0.21.0                                | `bafybeieqlozydyvdxmjxhqygwq27djecpiftoqwlcpcr4qpotomwnh66yy` |
| connection/valory/ledger/0.19.0                               | `bafybeift7fx4vp2jq4btplocifby2xnnbzxppxdttgyyvwepj5cv7akfom` |
| connection/valory/p2p_libp2p/0.1.0                            | `bafybeigfp2fjiqqcy5xess6kffcqp7eb2qmn2p6ihb6kgpul2ygcawtx2i` |
| connection/valory/p2p_libp2p_client/0.1.0                     | `bafybeidkk33xbga54szmitk6uwsi3ef56hbbdbuasltqtiyki34hgfpnxa` |
| connection/valory/p2p_libp2p_mailbox/0.1.0                    | `bafybeihjjsenbsgh6x2vukea7mqzsbcbqqbog6xa43raen24ewqf4qq3pm` |
| contract/fetchai/erc1155/0.22.0                               | `bafybeieq5xpb6k52csnzscdqrzo4yizoqxeim46pa5jltrmg7zhihcgspe` |
| protocol/fetchai/fipa/1.0.0                                   | `bafybeih27chr3b3anjeq26yd5c2p3hypp4sijzdu6yrorpwwxnvkeoa2ei` |
| protocol/fetchai/oef_search/1.0.0                             | `bafybeifiec4jvsa6mcbmasjno3bwvjwwwubyp25hjqwe7gjfksgvwgdisq` |
| protocol/fetchai/state_update/1.0.0                           | `bafybeidtndlmppst6l6iughpflqbbbkzditixo2fy2dncxfkb5apkx5y4m` |
| protocol/open_aea/signing/1.0.0                               | `bafybeiambqptflge33eemdhis2whik67hjplfnqwieoa6wblzlaf7vuo44` |
| skill/fetchai/echo/0.19.0                                     | `bafybeia3ovoxmnipktwnyztie55itsuempnfeircw72jn62uojzry5pwsu` |
| skill/fetchai/error_test_skill/0.1.0                          | `bafybeihsbtlpe7h6fsvoxban5rilkmwviwkokul5cqym6atoolirontiyu` |
| skill/fetchai/gym/0.20.0                                      | `bafybeiejzgnbm3mprvt3riytwbnlrl3bdqduubr5qqc7tfthheu36yoqua` |
| skill/fetchai/http_echo/0.20.0                                | `bafybeickwfnhufcaift5k6uspltvhatdpmppyhfzghewecctgq72dgu5a4` |
| agent/fetchai/error_test/0.1.0                                | `bafybeigercyzr4qscyf4bp22jwehyoxhcix6yyuxhfec2n5umns3qcm7aq` |
| agent/fetchai/gym_aea/0.25.0                                  | `bafybeicdufnk7w7kqfzznl3oor3br7ufxepvge5lvdhrf67ki6lbnuap74` |
| agent/fetchai/my_first_aea/0.27.0                             | `bafybeic6plxxhcbokxlce3grbgsm247rgvcb5arwwslm5yv6pt46byr22a` |
| agent/open_aea/gym_aea/0.1.0                                  | `bafybeidgnc6yoyzyjpekrcijhioe4orcfw325yjb4hw7mmfocbnd6z4rja` |
| agent/open_aea/http_echo/0.1.0                                | `bafybeifx3fqbwsggrm4ccztv56xt5xohgyf3g32ieryfxkm2jnuxo7raqq` |
| agent/open_aea/my_first_aea/0.1.0                             | `bafybeifelwg4md24lwpxgx7x5cugq7ovhbkew3lxw43m52rdppfn5o5g4i` |
| connection/fetchai/local/0.20.0                               | `bafybeianwid4lh3ubjheg4ho7qznuib2t6k35rcuconcbwtzmih4qdxo2i` |
| connection/valory/http_client/0.23.0                          | `bafybeihz3tubwado7j3wlivndzzuj3c6fdsp4ra5r3nqixn3ufawzo3wii` |
| connection/valory/test_libp2p/0.1.0                           | `bafybeibqoz7zp7vrlhw4glnwz4gby7ruugeib6whe6h4xrzjta5u2sbbi4` |
| protocol/fetchai/tac/1.0.0                                    | `bafybeiaew226n32rwp3h57zl4b2mmbrhjbyrdjbl2evnxf2tmmi4vrls7a` |
| skill/fetchai/erc1155_client/0.28.0                           | `bafybeidlrgyn4eonxl2sglzu36lmpo7say2pw7usvrfisbhjt2jtv7ht4e` |
| skill/fetchai/erc1155_deploy/0.30.0                           | `bafybeiexcya6etb5tn4nkcpvxuhvqextwbfvcznansn7dccfnqgff6kioq` |
| skill/fetchai/error/0.17.0                                    | `bafybeib7nhokw3bc46oxuk5mjazan42evipowmka2ikfcs6drcdz4mwkjm` |
| skill/fetchai/fipa_dummy_buyer/0.2.0                          | `bafybeiha4jultg5srhr2ijplvubeo7esv4raq2cjlggmyzcaimop2ggg2m` |
| skill/fetchai/generic_buyer/0.26.0                            | `bafybeiht376to56oeutzpxoyoijv4i76sydyiou3ydwfmzta4l4kljotmm` |
| skill/fetchai/generic_seller/0.27.0                           | `bafybeif5y3nv2gdj72uzzlqt2ntdhnjeq433srxxq6p3q2gu4wcddnbh7i` |
| skill/fetchai/task_test_skill/0.1.0                           | `bafybeidv77u2xl52mnxakwvh7fuh46aiwfpteyof4eaptfd4agoi6cdble` |
